Module database

Structs

DatabaseConfig
NoTls
A MakeTlsConnect and TlsConnect implementation which simply returns an error.
PooledDbClient
Row
A row of data returned from the database by a query.
ThreadedDbClient

Enums

DbClient

Traits

DatabaseRequest
ToSql
A trait for types that can be converted into Postgres values.
ToStatement
A trait abstracting over prepared and unprepared statements.

Functions

connect_to_database
database_test_config
drop_and_recreate_database
spawn_thread_db_client

Type Aliases

DatabaseRequestBoxed