Struct DatabaseConfig

pub struct DatabaseConfig {
Show 17 fields pub user: Option<String>, pub password: Option<SecretString>, pub dbname: Option<String>, pub options: Option<String>, pub application_name: Option<String>, pub ssl_mode: Option<SslMode>, pub host: Option<String>, pub hosts: Option<Vec<String>>, pub port: Option<u16>, pub ports: Option<Vec<u16>>, pub connect_timeout: Option<Duration>, pub keepalives: Option<bool>, pub keepalives_idle: Option<Duration>, pub target_session_attrs: Option<TargetSessionAttrs>, pub channel_binding: Option<ChannelBinding>, pub manager: Option<ManagerConfig>, pub pool: Option<PoolConfig>,
}

Fields

user: Option<String>password: Option<SecretString>dbname: Option<String>options: Option<String>application_name: Option<String>ssl_mode: Option<SslMode>host: Option<String>

This is similar to Config::hosts but only allows one host to be specified.

Unlike tokio_postgres::Config this structure differentiates between one host and more than one host. This makes it possible to store this configuration in an environment variable.

See tokio_postgres::Config::host.

hosts: Option<Vec<String>>port: Option<u16>

This is similar to Config::ports but only allows one port to be specified.

Unlike tokio_postgres::Config this structure differentiates between one port and more than one port. This makes it possible to store this configuration in an environment variable.

See tokio_postgres::Config::port.

ports: Option<Vec<u16>>connect_timeout: Option<Duration>keepalives: Option<bool>keepalives_idle: Option<Duration>target_session_attrs: Option<TargetSessionAttrs>channel_binding: Option<ChannelBinding>manager: Option<ManagerConfig>

Manager configuration.

pool: Option<PoolConfig>

Pool configuration.