Module log

Module log 

Tracing-based logging setup with stdout and file logging support

Re-exports

pub use level_filter::*;

Modules

legacyDeprecated
Deprecated logging utilities from previous implementations
level_filter
Log level enum and environment filter builder

Structs

CustomEyreHandler
This is used to wrap the default EyreHandler but simply expose the CustomEyreHandler::location field via CustomEyreHandler::get_location This allows the code in [crate::libs::ws::internal_error_to_resp] to access the original caller location which is then stored in a [tracing::Field] for access within [error_aggregation::ErrorAggregationLayer::on_event] (see trait impl) so that the original caller can be recorded within the displayed target
FileLoggingConfig
LogReloadHandle
Handle for reloading the global log level at runtime
LogRotation
Defines a fixed period for rolling of a log file.
LogSetupReturn
LogThrottlingConfig
LoggingConfig
WorkerGuard
A guard that flushes spans/events associated to a NonBlocking on a drop

Functions

setup_logging
Sets up a fully filtered tracing logging system with a global env filter applied at the registry level. This ensures all layers (stdout, file, etc.) only receive events that pass the global filter.

Type Aliases

GlobalLogReloadHandle
Handle for reloading the global EnvFilter at runtime