pub struct DynLogger { /* private fields */ }👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
Implementations
Sourceimpl DynLogger
impl DynLogger
pub fn new(logger: Arc<dyn Fn(&str) + Send + Sync>) -> Self
👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
pub fn empty() -> Self
👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
pub fn log(&self, msg: impl AsRef<str>)
👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward