pub struct CustomEyreHandler { /* private fields */ }Expand description
This is used to wrap the default EyreHandler but simply expose the CustomEyreHandler::location field via CustomEyreHandler::get_location This allows the code in [crate::libs::ws::internal_error_to_resp] to access the original caller location which is then stored in a [tracing::Field] for access within [error_aggregation::ErrorAggregationLayer::on_event] (see trait impl) so that the original caller can be recorded within the displayed target
Implementations
Sourceimpl CustomEyreHandler
impl CustomEyreHandler
pub fn default_with_location_saving( error: &(dyn Error + 'static), ) -> Box<dyn EyreHandler>
pub fn get_location(&self) -> &Option<&'static Location<'static>>