pub struct LogReloadHandle(/* private fields */);Expand description
Handle for reloading the global log level at runtime
Implementations
Sourceimpl LogReloadHandle
impl LogReloadHandle
Sourcepub fn set_log_level(&self, level: LogLevel) -> Result<()>
pub fn set_log_level(&self, level: LogLevel) -> Result<()>
Sets a new global log level that applies to all layers (stdout, file, etc.) Errors will be logged by this function and can be safely ignored, but are returned for display purposes