pub struct LogRotation(/* private fields */);Expand description
Defines a fixed period for rolling of a log file.
To use a Rotation, pick one of the following options:
Minutely Rotation
use tracing_appender::rolling::Rotation;
let rotation = tracing_appender::rolling::Rotation::MINUTELY;Hourly Rotation
use tracing_appender::rolling::Rotation;
let rotation = tracing_appender::rolling::Rotation::HOURLY;Daily Rotation
use tracing_appender::rolling::Rotation;
let rotation = tracing_appender::rolling::Rotation::DAILY;Weekly Rotation
use tracing_appender::rolling::Rotation;
let rotation = tracing_appender::rolling::Rotation::WEEKLY;No Rotation
use tracing_appender::rolling::Rotation;
let rotation = tracing_appender::rolling::Rotation::NEVER;Implementations