pub struct LogThrottlingConfig {
pub summary_emission_interval: Option<Duration>,
pub metrics_emission_interval: Option<Duration>,
pub excluded_fields: Option<Vec<String>>,
pub exemptions: Option<Vec<String>>,
}Fields
summary_emission_interval: Option<Duration>How often to emit throttling summaries as WARN events, set to None to disable entirely
metrics_emission_interval: Option<Duration>How often to throttling metrics as INFO events, set to None to disable entirely
excluded_fields: Option<Vec<String>>Fields to exclude from uniqueness checks, set to None to disable entirely.
Example:
ⓘ
tracing::info!(user_id=1, "User joined");
tracing::info!(user_id=2, "User joined"); If the user_id field is excluded, these will be treated as exactly the same log, so multiple users join messages could be throttled
exemptions: Option<Vec<String>>Targets to exempt from any throttling. This allows the caller to ensure that any high priority logs are always displayed.
Example:
ⓘ
let exemptions = Some(vec!["nothrottle"]); // Assuming this is passed during config stage
tracing::error!(target: "nothrottle", user_id=1, "User joined"); // Will never be throttled
tracing::error!(user_id=2, "User joined"); // Can possibly be throttledTrait Implementations
Sourceimpl Clone for LogThrottlingConfig
impl Clone for LogThrottlingConfig
Sourcefn clone(&self) -> LogThrottlingConfig
fn clone(&self) -> LogThrottlingConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogThrottlingConfig
impl Debug for LogThrottlingConfig
Sourceimpl Default for LogThrottlingConfig
impl Default for LogThrottlingConfig
Sourcefn default() -> LogThrottlingConfig
fn default() -> LogThrottlingConfig
Returns the “default value” for a type. Read more