pub struct VerifyProtocol<'a> {
pub addr: SocketAddr,
pub tx: Sender<String>,
pub allow_cors_domains: &'a Option<Vec<String>>,
}Fields
addr: SocketAddrtx: Sender<String>allow_cors_domains: &'a Option<Vec<String>>Trait Implementations
Sourceimpl Callback for VerifyProtocol<'_>
impl Callback for VerifyProtocol<'_>
Sourcefn on_request(
self,
request: &Request,
response: Response,
) -> Result<Response, ErrorResponse>
fn on_request( self, request: &Request, response: Response, ) -> Result<Response, ErrorResponse>
Called whenever the server read the request from the client and is ready to reply to it.
May return additional reply headers.
Returning an error resulting in rejecting the incoming connection.