pub struct EndpointSchema {
pub name: String,
pub code: u32,
pub parameters: Vec<Field>,
pub returns: Vec<Field>,
pub stream_response: Option<Type>,
pub description: String,
pub json_schema: Value,
pub roles: Vec<String>,
pub errors: Vec<EndpointErrorSchema>,
}Expand description
EndpointSchema is a struct that represents a single endpoint in the API.
Fields
name: StringThe name of the endpoint (e.g. UserListSymbols)
code: u32The method code of the endpoint (e.g. 10020)
parameters: Vec<Field>A list of parameters that the endpoint accepts (e.g. “symbol” of type String)
returns: Vec<Field>A list of fields that the endpoint returns
stream_response: Option<Type>The type of the stream response (if any)
description: StringA description of the endpoint added by with_description method
json_schema: ValueThe JSON schema of the endpoint (Default::default())
roles: Vec<String>errors: Vec<EndpointErrorSchema>Public error variants that handlers may return for this endpoint.
Implementations
Sourceimpl EndpointSchema
impl EndpointSchema
Sourcepub fn new(
name: impl Into<String>,
code: u32,
parameters: Vec<Field>,
returns: Vec<Field>,
) -> Self
pub fn new( name: impl Into<String>, code: u32, parameters: Vec<Field>, returns: Vec<Field>, ) -> Self
Creates a new EndpointSchema with the given name, method code, parameters and returns.
Sourcepub fn with_stream_response_type(self, stream_response: Type) -> Self
pub fn with_stream_response_type(self, stream_response: Type) -> Self
Adds a stream response type field to the endpoint.
Sourcepub fn with_description(self, desc: impl Into<String>) -> Self
pub fn with_description(self, desc: impl Into<String>) -> Self
Adds a description field to the endpoint.
Sourcepub fn with_roles(self, roles: Vec<String>) -> Self
pub fn with_roles(self, roles: Vec<String>) -> Self
Adds allowed roles to the endpoint.
Sourcepub fn with_errors(self, errors: Vec<EndpointErrorSchema>) -> Self
pub fn with_errors(self, errors: Vec<EndpointErrorSchema>) -> Self
Adds public error variants to the endpoint.