Module types

Module types 

Structs

EnumVariant
EnumVariant is a struct that represents the variants of an enum.
Field
Field is a struct that represents the parameters and returns in an endpoint schema.

Enums

Type
Type is an enum that represents the types of the fields in an endpoint schema.