#[non_exhaustive]pub struct Field {
pub name: String,
pub description: String,
pub ty: Type,
pub meta: MetaMap,
}Expand description
Field is a struct that represents the parameters and returns in an endpoint schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the field (e.g. user_id)
description: StringThe description of the field
ty: TypeThe type of the field (e.g. Type::BigInt)
meta: MetaMapEmitter annotations — see MetaMap. Empty in 2.0.
Implementations
Sourceimpl Field
impl Field
Sourcepub fn new(name: impl Into<String>, ty: Type) -> Self
pub fn new(name: impl Into<String>, ty: Type) -> Self
Creates a new Field with the given name and type.
description is set to "".