ErrorCode

Struct ErrorCode 

pub struct ErrorCode { /* private fields */ }
ErrorCode is a wrapper around u32 that represents an error code.

Implementations

Source

impl ErrorCode

pub const BAD_REQUEST: Self

Indicated a bad request.

pub const UNAUTHORIZED: Self

Indicates that authentication is required.

pub const PAYMENT_REQUIRED: Self

Indicates that payment is required.

pub const FORBIDDEN: Self

Indicates forbidden access.

pub const NOT_FOUND: Self

Indicates that the requested resource was not found.

pub const METHOD_NOT_ALLOWED: Self

Indicates that the request method is not allowed.

pub const NOT_ACCEPTABLE: Self

Indicates that the requested response format is not acceptable.

pub const PROXY_AUTHENTICATION_REQUIRED: Self

Indicates that proxy authentication is required.

pub const REQUEST_TIMEOUT: Self

Indicates that the request timed out.

pub const CONFLICT: Self

Indicates that the request conflicts with current state.

pub const GONE: Self

Indicates that the requested resource is gone.

pub const LENGTH_REQUIRED: Self

Indicates that the request must include a content length.

pub const PRECONDITION_FAILED: Self

Indicates that a precondition failed.

pub const PAYLOAD_TOO_LARGE: Self

Indicates that the payload is too large.

pub const URI_TOO_LONG: Self

Indicates that the URI is too long.

pub const UNSUPPORTED_MEDIA_TYPE: Self

Indicates that the media type is unsupported.

pub const RANGE_NOT_SATISFIABLE: Self

Indicates that the requested range cannot be satisfied.

pub const EXPECTATION_FAILED: Self

Indicates that an expectation failed.

pub const IM_A_TEAPOT: Self

Indicates an I’m a teapot response.

pub const MISDIRECTED_REQUEST: Self

Indicates that the request was misdirected.

pub const UNPROCESSABLE_ENTITY: Self

Indicates that the entity could not be processed.

pub const LOCKED: Self

Indicates that the resource is locked.

pub const FAILED_DEPENDENCY: Self

Indicates a failed dependency.

pub const UPGRADE_REQUIRED: Self

Indicates that the request must be upgraded.

pub const PRECONDITION_REQUIRED: Self

Indicates that a precondition is required.

pub const TOO_MANY_REQUESTS: Self

Indicates too many requests.

pub const REQUEST_HEADER_FIELDS_TOO_LARGE: Self

Indicates that request header fields are too large.

Indicates that the request is unavailable for legal reasons.

pub const INTERNAL_ERROR: Self

Indicates an internal server error.

pub const NOT_IMPLEMENTED: Self

Indicates a non-implemented endpoint.

pub const BAD_GATEWAY: Self

Indicates a bad gateway.

pub const SERVICE_UNAVAILABLE: Self

Indicates that the service is unavailable.

pub const GATEWAY_TIMEOUT: Self

Indicates a gateway timeout.

pub const HTTP_VERSION_NOT_SUPPORTED: Self

Indicates that the HTTP version is not supported.

pub const VARIANT_ALSO_NEGOTIATES: Self

Indicates that content negotiation also found a variant problem.

pub const INSUFFICIENT_STORAGE: Self

Indicates insufficient storage.

pub const LOOP_DETECTED: Self

Indicates that a loop was detected.

pub const NOT_EXTENDED: Self

Indicates that the request must be extended.

pub const NETWORK_AUTHENTICATION_REQUIRED: Self

Indicates that network authentication is required.

pub const fn new(code: u32) -> Self

Create a new ErrorCode from a u32.

pub const fn to_u32(self) -> u32

Get the ErrorCode as a u32. Just returns the code field.

pub const fn code(self) -> u32

Getter for the ErrorCode code field.

pub const fn kind(self) -> &'static str

pub fn from_name(name: &str) -> Option<Self>