pub enum LoggingGuard {
NonBlocking(WorkerGuard, PathBuf),
StdoutWithPath(Option<PathBuf>),
}👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
Variants
NonBlocking(WorkerGuard, PathBuf)
👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
StdoutWithPath(Option<PathBuf>)
👎Deprecated since 1.3.0: This code is not used in current projects and should probably not be used going forward
Implementations