Structs
- Enum
Variant EnumVariantis a struct that represents the variants of an enum.- Field
Fieldis a struct that represents the parameters and returns in an endpoint schema.
Enums
- Type
Typeis an enum that represents the types of the fields in an endpoint schema.